import os
import numpy as np
from montepython.likelihood_class import Likelihood
from scipy import interpolate

class bard_qg_low_ell(Likelihood):

    # initialization routine
    def __init__(self, path, data, command_line):

        Likelihood.__init__(self, path, data, command_line)
        self.ell = np.array([], 'float64')
        self.c_ell = np.array([], 'float64')
        self.sigma = np.array([], 'float64')

        
        for line in open(os.path.join(self.data_directory, self.data_file), 'r'):
            if (line.find('#') == -1):
                self.ell = np.append(self.ell, float(line.split()[0]))
                self.c_ell = np.append(self.c_ell, float(line.split()[1]))
                self.sigma = np.append(self.sigma, float(line.split()[2]))
 
                
        self.num_points = np.shape(self.ell)[0]

  

        
    # compute likelihood
    def loglkl(self, cosmo, data):
        covmat = np.zeros((self.num_points, self.num_points), 'float64')
	      
        for i in range(self.num_points):
          for j in range(self.num_points):
            if i==j:
              covmat[i][j] = self.sigma[i]*self.sigma[i]
            else:          
	      covmat[i][j] = 0.            


             
        inv_covmat = np.linalg.inv(covmat)
        det_covmat = np.linalg.det(covmat)
        
        # define array for difference between theory and observations
        difference = np.ndarray(self.num_points, 'float64')
        
        
        c_p = cosmo.raw_cl()['tt'][2:30]
        e_p = cosmo.raw_cl()['ell'][2:30]
        c_ell = e_p*(e_p+1.)/2./np.pi*c_p*1e12*cosmo.T_cmb()**2.
        
    


        for i in range(self.num_points):
            difference[i] = (self.c_ell[i]-c_ell[i])

        AT = np.dot(difference, np.dot(inv_covmat, difference))

        chi2 = AT
        return  - 0.5*chi2
